@@ -24,11 +24,11 @@
 #include <stdarg.h>
 
 #define ERROR 0
-#define INFO 1
-#define DEBUG 2
+#define WARNING 1
+#define INFO 2
+#define DEBUG 3
 
 #define log(level, format, ...) \
 	    debug_log(__func__, level, format, ##__VA_ARGS__)
 
-void debug_log(const char *func, int level, const char *format, ...)
-	       __attribute__((__format__(printf, 3, 4)));
+static void debug_log(const char *func, int level, const char *format, ...) __attribute__((__format__(printf, 3, 4)));
